var camera, scene, renderer;

var mesh;

var mixer;
var clock = new THREE.Clock();
var action = {};


init();
animate();


function init() {

  renderer = new THREE.WebGLRenderer({antialias: true});
  renderer.setClearColor (0xffffff);
  renderer.setPixelRatio( window.devicePixelRatio );
  renderer.setSize( window.innerWidth, window.innerHeight );
  document.body.appendChild( renderer.domElement );

  camera = new THREE.PerspectiveCamera( 45, window.innerWidth / window.innerHeight, 1, 2000 );
  camera.position.z = 250;
  camera.position.y = 40;


  scene = new THREE.Scene();

  var ambient = new THREE.AmbientLight( 0xeeeeee );
  scene.add( ambient );


  var loader = new THREE.JSONLoader();


  // MODEL_URL is defined in html file
  loader.load( MODEL_URL, function( geometry, materials ) {

    console.log(geometry, materials);
     
    if ( materials ) {
     
        materials.forEach( function ( material ) {

            material.skinning = true;

        } );
    }
    

    mesh = new THREE.SkinnedMesh( geometry );

    mesh = new THREE.SkinnedMesh(
      geometry,
      new THREE.MeshFaceMaterial( materials )
    );


    // MODEL_SCALE is defined in html file
    if ( typeof MODEL_SCALE !== "undefined" ) {
      //for monster
      mesh.scale.x = mesh.scale.y = mesh.scale.z = MODEL_SCALE;

    } else {

      mesh.scale.x = mesh.scale.y = mesh.scale.z = 30;

    }
    

    mixer  = new THREE.AnimationMixer( mesh );
    action.idle  = mixer.clipAction( geometry.animations[ 0 ] );
    action.idle.play();

    console.log( mesh );

    scene.add( mesh );

  } );
  


  window.addEventListener( 'resize', onWindowResize, false );

}

function onWindowResize() {

  camera.aspect = window.innerWidth / window.innerHeight;
  camera.updateProjectionMatrix();

  renderer.setSize( window.innerWidth, window.innerHeight );

}



function animate() {

  if (mesh) {
    mesh.rotation.y += 0.02;
  }

  if ( mixer ) { 

    mixer.update( clock.getDelta() ); 

  }

  renderer.render( scene, camera );

  requestAnimationFrame( animate );

}
